@@ -32,13 +32,12 @@ LearnerClassifLDA = R6Class("LearnerClassifLDA",
       ps = ps(
         dimen          = p_uty(tags = "predict"),
         method         = p_fct(c("moment", "mle", "mve", "t"), default = "moment", tags = "train"),
-        nu             = p_int(tags = "train"),
+        nu             = p_int(tags = "train", depends = quote(method == "t")),
         predict.method = p_fct(c("plug-in", "predictive", "debiased"), default = "plug-in", tags = "predict"),
         predict.prior  = p_uty(tags = "predict"),
         prior          = p_uty(tags = "train"),
         tol            = p_dbl(tags = "train")
       )
-      ps$add_dep("nu", "method", CondEqual$new("t"))
 
       super$initialize(
         id = "classif.lda",
