@@ -67,73 +67,57 @@ LearnerRegrXgboost = R6Class("LearnerRegrXgboost",
         early_stopping_set          = p_fct(c("none", "train", "test"), default = "none", tags = "train"),
         eta                         = p_dbl(0, 1, default = 0.3, tags = "train"),
         eval_metric                 = p_uty(default = "rmse", tags = "train"),
-        feature_selector            = p_fct(c("cyclic", "shuffle", "random", "greedy", "thrifty"), default = "cyclic", tags = "train"),
+        feature_selector            = p_fct(c("cyclic", "shuffle", "random", "greedy", "thrifty"), default = "cyclic", tags = "train", depends = quote(booster == "gblinear")),
         feval                       = p_uty(default = NULL, tags = "train"),
         gamma                       = p_dbl(0, default = 0, tags = "train"),
-        grow_policy                 = p_fct(c("depthwise", "lossguide"), default = "depthwise", tags = "train"),
+        grow_policy                 = p_fct(c("depthwise", "lossguide"), default = "depthwise", tags = "train", depends = quote(tree_method == "hist")),
         interaction_constraints     = p_uty(tags = "train"),
         iterationrange              = p_uty(tags = "predict"),
         lambda                      = p_dbl(0, default = 1, tags = "train"),
-        lambda_bias                 = p_dbl(0, default = 0, tags = "train"),
-        max_bin                     = p_int(2L, default = 256L, tags = "train"),
+        lambda_bias                 = p_dbl(0, default = 0, tags = "train", depends = quote(booster == "gblinear")),
+        max_bin                     = p_int(2L, default = 256L, tags = "train", depends = quote(tree_method == "hist")),
         max_delta_step              = p_dbl(0, default = 0, tags = "train"),
         max_depth                   = p_int(0L, default = 6L, tags = "train"),
-        max_leaves                  = p_int(0L, default = 0L, tags = "train"),
+        max_leaves                  = p_int(0L, default = 0L, tags = "train", depends = quote(grow_policy == "lossguide")),
         maximize                    = p_lgl(default = NULL, special_vals = list(NULL), tags = "train"),
         min_child_weight            = p_dbl(0, default = 1, tags = "train"),
         missing                     = p_dbl(default = NA, tags = c("train", "predict"), special_vals = list(NA, NA_real_, NULL)),
         monotone_constraints        = p_uty(default = 0, tags = c("train", "control"), custom_check = crate(function(x) { checkmate::check_integerish(x, lower = -1, upper = 1, any.missing = FALSE) })), # nolint
-        normalize_type              = p_fct(c("tree", "forest"), default = "tree", tags = "train"),
+        normalize_type              = p_fct(c("tree", "forest"), default = "tree", tags = "train", depends = quote(booster == "dart")),
         nrounds                     = p_int(1L, tags = c("train", "hotstart")),
         nthread                     = p_int(1L, default = 1L, tags = c("train", "threads")),
         ntreelimit                  = p_int(1, default = NULL, special_vals = list(NULL), tags = "predict"),
         num_parallel_tree           = p_int(1L, default = 1L, tags = "train"),
         objective                   = p_uty(default = "reg:squarederror", tags = c("train", "predict")),
-        one_drop                    = p_lgl(default = FALSE, tags = "train"),
+        one_drop                    = p_lgl(default = FALSE, tags = "train", depends = quote(booster == "dart")),
         outputmargin                = p_lgl(default = FALSE, tags = "predict"),
         predcontrib                 = p_lgl(default = FALSE, tags = "predict"),
         predinteraction             = p_lgl(default = FALSE, tags = "predict"),
         predleaf                    = p_lgl(default = FALSE, tags = "predict"),
-        print_every_n               = p_int(1L, default = 1L, tags = "train"),
+        print_every_n               = p_int(1L, default = 1L, tags = "train", depends = quote(verbose == 1L)),
         process_type                = p_fct(c("default", "update"), default = "default", tags = "train"),
-        rate_drop                   = p_dbl(0, 1, default = 0, tags = "train"),
+        rate_drop                   = p_dbl(0, 1, default = 0, tags = "train", depends = quote(booster == "dart")),
         refresh_leaf                = p_lgl(default = TRUE, tags = "train"),
         reshape                     = p_lgl(default = FALSE, tags = "predict"),
-        sampling_method             = p_fct(c("uniform", "gradient_based"), default = "uniform", tags = "train"),
-        sample_type                 = p_fct(c("uniform", "weighted"), default = "uniform", tags = "train"),
+        sampling_method             = p_fct(c("uniform", "gradient_based"), default = "uniform", tags = "train", depends = quote(booster == "gbtree")),
+        sample_type                 = p_fct(c("uniform", "weighted"), default = "uniform", tags = "train", depends = quote(booster == "dart")),
         save_name                   = p_uty(default = NULL, tags = "train"),
         save_period                 = p_int(0, default = NULL, special_vals = list(NULL), tags = "train"),
         scale_pos_weight            = p_dbl(default = 1, tags = "train"),
         seed_per_iteration          = p_lgl(default = FALSE, tags = "train"),
-        skip_drop                   = p_dbl(0, 1, default = 0, tags = "train"),
+        skip_drop                   = p_dbl(0, 1, default = 0, tags = "train", depends = quote(booster == "dart")),
         strict_shape                = p_lgl(default = FALSE, tags = "predict"),
         subsample                   = p_dbl(0, 1, default = 1, tags = "train"),
-        top_k                       = p_int(0, default = 0, tags = "train"),
+        top_k                       = p_int(0, default = 0, tags = "train", depends = quote(booster == "gblinear" && feature_selector %in% c("greedy", "thrifty"))),
         training                    = p_lgl(default = FALSE, tags = "predict"),
-        tree_method                 = p_fct(c("auto", "exact", "approx", "hist", "gpu_hist"), default = "auto", tags = "train"),
-        tweedie_variance_power      = p_dbl(1, 2, default = 1.5, tags = "train"),
+        tree_method                 = p_fct(c("auto", "exact", "approx", "hist", "gpu_hist"), default = "auto", tags = "train", depends = quote(booster %in% c("gbtree", "dart"))),
+        tweedie_variance_power      = p_dbl(1, 2, default = 1.5, tags = "train", depends = quote(objective == "reg:tweedie")),
         updater                     = p_uty(tags = "train"), # Default depends on the selected booster
         verbose                     = p_int(0L, 2L, default = 1L, tags = "train"),
         watchlist                   = p_uty(default = NULL, tags = "train"),
         xgb_model                   = p_uty(default = NULL, tags = "train")
       )
       # param deps
-      ps$add_dep("tweedie_variance_power", "objective", CondEqual$new("reg:tweedie"))
-      ps$add_dep("print_every_n", "verbose", CondEqual$new(1L))
-      ps$add_dep("sampling_method", "booster", CondEqual$new("gbtree"))
-      ps$add_dep("sample_type", "booster", CondEqual$new("dart"))
-      ps$add_dep("normalize_type", "booster", CondEqual$new("dart"))
-      ps$add_dep("rate_drop", "booster", CondEqual$new("dart"))
-      ps$add_dep("skip_drop", "booster", CondEqual$new("dart"))
-      ps$add_dep("one_drop", "booster", CondEqual$new("dart"))
-      ps$add_dep("tree_method", "booster", CondAnyOf$new(c("gbtree", "dart")))
-      ps$add_dep("grow_policy", "tree_method", CondEqual$new("hist"))
-      ps$add_dep("max_leaves", "grow_policy", CondEqual$new("lossguide"))
-      ps$add_dep("max_bin", "tree_method", CondEqual$new("hist"))
-      ps$add_dep("feature_selector", "booster", CondEqual$new("gblinear"))
-      ps$add_dep("top_k", "booster", CondEqual$new("gblinear"))
-      ps$add_dep("top_k", "feature_selector", CondAnyOf$new(c("greedy", "thrifty")))
-      ps$add_dep("lambda_bias", "booster", CondEqual$new("gblinear"))
 
       # custom defaults
       ps$values = list(nrounds = 1L, nthread = 1L, verbose = 0L, early_stopping_set = "none")
@@ -231,5 +215,15 @@ LearnerRegrXgboost = R6Class("LearnerRegrXgboost",
   )
 )
 
+#' @export
+default_values.LearnerRegrXgboost = function(x, search_space, task, ...) { # nolint
+  special_defaults = list(
+    nrounds = 1L
+  )
+  defaults = insert_named(default_values(x$param_set), special_defaults)
+  defaults[search_space$ids()]
+}
+
+
 #' @include aaa.R
 learners[["regr.xgboost"]] = LearnerRegrXgboost
