@@ -16,13 +16,17 @@ test_that("regr.ranger", {
     "dependent.variable.name", # handled via mlr3
     "status.variable.name", # handled via mlr3
     "classification", # handled via mlr3
-    "mtry.ratio" # custom hyperpar
+    "mtry.ratio", # custom hyperpar
+    "time.interest" # survival only
   )
 
-  ParamTest = run_paramtest(learner, fun, exclude)
+  ParamTest = run_paramtest(learner, fun, exclude, tag = "train")
   expect_true(ParamTest, info = paste0(
-    "Missing parameters:",
-    paste0("- '", ParamTest$missing, "'", collapse = ",")))
+    "\nMissing parameters in mlr3 param set:\n",
+    paste0("- ", ParamTest$missing, "\n", collapse = ""),
+    "\nOutdated param or param defined in additional control function not included in list of function definitions:\n",
+    paste0("- ", ParamTest$extra, "\n", collapse = ""))
+    )
 })
 
 test_that("predict regr.ranger", {
@@ -38,8 +42,11 @@ test_that("predict regr.ranger", {
     "type" # handled via mlr3
   )
 
-  ParamTest = run_paramtest(learner, fun, exclude)
+  ParamTest = run_paramtest(learner, fun, exclude, tag = "predict")
   expect_true(ParamTest, info = paste0(
-    "Missing parameters:",
-    paste0("- '", ParamTest$missing, "'", collapse = ",")))
+    "\nMissing parameters in mlr3 param set:\n",
+    paste0("- ", ParamTest$missing, "\n", collapse = ""),
+    "\nOutdated param or param defined in additional control function not included in list of function definitions:\n",
+    paste0("- ", ParamTest$extra, "\n", collapse = ""))
+    )
 })
