@@ -1,5 +1,5 @@
+skip_on_os("solaris") # glmnet not working properly on solaris
 skip_if_not_installed("glmnet")
-skip_on_os("solaris")
 
 test_that("autotest", {
   learner = mlr3::lrn("classif.glmnet", lambda = .1)
